==> rktSNS_1.070120.tgz: rktSNS/webapp/libs/community/pictures.php <==
<?php
/* ========================================================================
 - [webapp/libs/community/pictures.php]
 -      コミュニティ関連の添付画像クラス
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/07/10] 作成
 - ======================================================================== */

require_once LIB_DIR.'rkt_db.php';
require_once LIB_DIR.'rkt_upload.php';

/**
 * コミュニティ関連の添付画像クラス
 *
 * @author 高橋 裕志郎 <yujiro@stepone.tv>
 * @package community_body
 * @access public
 * @version 1.0
 */
class community_pictures
{
    /**
     * 添付ファイル画像ID
     * @var integer
     */
    var $ids = 0;

    /**
     * コミュニティID
     * @var boolean
     */
    var $ref_community = 0;

    /**
     * ID
     * @var integer
     */
    var $ref_relation = 0;

    /**
     * アカウントID
     * @var integer
     */
    var $ref_account = 0;

    /**
     * ステータス
     * @var integer
     */
    var $status = 0;

    /**
     * DB接続オジェクト
     * @var object
     */
    var $objdb = null;

    /**
     * BLOB操作オブジェクト
     * @var object
     */
    var $objfile = null;

    /**
     * コンストラクタ
     *
     * @access public
     * @param integer $ref_community
     * @param integer $ref_relation
     * @return void
     */
    function community_pictures($ref_community, $ref_relation, $status)
    {
        $this->objdb = RKT_db::getInstance();
        $this->objfile = RKT_upload::getInstance(BLOB_DRIVER,BLOB_PARAM); 

        $this->ref_community = $ref_community;
        $this->ref_relation = empty($ref_relation)?0:$ref_relation;
        $objact = account::getInstance();
        $this->ref_account = $objact->getInfo('id');
        $this->status = $status;        
        $this->set_ids();

        /* 削除画像IDの引継ぎ */
        if (!empty($_POST['picture_delete'])){
            $deletes = array();
            foreach ($_POST['picture_delete'] as $id) {
                $deletes[$id] = $id;
            }
            $_SESSION['picture_delete'] = $deletes;
        } // if (!empty($_POST['picture_delete']))
    }

    /**
     * 添付ファイルIDの取得
     *
     * @access private
     * @return void
     */
    function set_ids()
    {
        if (isSet($_SESSION['ref_pictures'])){
            $this->ids = $_SESSION['ref_pictures'];
            return ;
        } // if (isSet($_SESSION['ref_pictures']))

        $where = ' AND ref_relation = '.$this->ref_relation;
        /* コミュニティよう添付画像 */
        if ($this->status == STATUS_PICTURE_COMMUNITY){
            $where = '';
        }
        
        $sql=
            'SELECT '.
                'id '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'ref_community = '.$this->ref_community.' AND '.
                'status = '.$this->status.
                $where;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        $this->ids = array();
        if (empty($result)){
            return ;
        }

        foreach ($result as $value){
            $this->ids[$value['id']] = $value['id'];
        }
    }

    /**
     * 画像のアップロード処理
     *
     * @access public
     * @return integer  データ操作結果
     */
    function doUpload()
    {
        if (empty($_POST['ref_pictures'])){
            return ;
        }

        $this->ids = array();
        $row = 0;
        foreach ($_POST['ref_pictures'] as $id) {
            if (!empty($id)){
                $this->ids[$id] = $id;
            }
            $this->upload($id, 'photo'.$row);
            $row++;
        }
        $_SESSION['ref_pictures'] = $this->ids;
    }

    /**
     * 画像のアップロード処理
     *
     * @access public
     * @return integer  データ操作結果
     */
    function upload($id, $name)
    {
        /* 一覧用画像 */
        if (!$this->objfile->catchFile($name)) {
            return false;
        }
        if (!$this->objfile->isImage()){
            return false;
        }

        // ファイルの保存
        $dir = ARCHIVES_UPLOAD_PATH;
        $filename = $this->objfile->getName();
        $extension = $this->objfile->getExtension();

        $temp = md5($this->ref_account.time());
        $name = substr($temp, rand(0,25), 6);

        $large_path = $dir.'large/'.$name.'.'.$extension;
        $small_path = $dir.'small/'.$name.'.'.$extension;

        $large = $this->objfile->saveResize($large_path,PHOTO_MAX_SIZE, PHOTO_MAX_SIZE);
        $small = $this->objfile->saveResize($small_path,PHOTO_SMALL_SIZE,PHOTO_SMALL_SIZE);

        $values = array(
            'title'=> $filename,
            'filename'=> $large_path,
            'width'=> $large['width'],
            'height'=> $large['height'],
            'thumbnail'=> $small_path,
            't_width'=> $small['width'],
            't_height'=> $small['height'],
        );

        if (empty($id)){
            $this->insert($values);
        } else {
            $this->update($id,$values);
        }
        return true;
    }

    /**
     * 添付画像を新規登録
     *
     * @access private
     * @param array $values
     * @return boolean  真偽値
     */
    function insert($values)
    {
        $sql =
            'INSERT INTO '.
                DB_PREFIX.'com_picture('.
                    'modify,'.
                    'ref_community,'.
                    'ref_account,'.
                    'title,'.
                    'filename,'.
                    'width,'.
                    'height,'.
                    'thumbnail,'.
                    't_width,'.
                    't_height'.
                ') VALUES ('.
                    "'".date('Y-m-d H:i:s')."',".
                    $this->ref_community.','.
                    $this->ref_account.','.
                    "'".$values['title']."',".
                    "'".$values['filename']."',".
                    $values['width'].','.
                    $values['height'].','.
                    "'".$values['thumbnail']."',".
                    $values['t_width'].','.
                    $values['t_height'].
                ')';
        $result = $this->objdb->exec($sql);
        if ($result){
            $id = $this->objdb->lastInsertId();
            $this->ids[$id] = $id;
        }
        return $result;
    }

    /**
     * 添付画像を更新
     *
     * @access private
     * @param integer $id
     * @param array $values
     * @return boolean  真偽値
     */
    function update($id,$values)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (!empty($result)){
            $this->objfile->unlink($result['filename']);
            $this->objfile->unlink($result['thumbnail']);
        }

        $sql =
            'UPDATE '.
                DB_PREFIX.'com_picture '.
            'SET '.
                "modify='".date('Y-m-d H:i:s')."',".
                "title='".$values['title']."',".
                "filename='".$values['filename']."',".
                'width='.$values['width'].','.
                'height='.$values['height'].','.
                "thumbnail='".$values['thumbnail']."',".
                't_width='.$values['t_width'].','.
                't_height='.$values['t_height'].' '.
            'WHERE '.
                'id = '.$id;
        $result = $this->objdb->exec($sql);
        if ($result){
            $this->ids[$id] = $id;
        }
        return $result;
    }

    /**
     * 画像の削除
     *
     * @access public
     * @param boolean $cahtch
     * @return integer  データ操作結果
     */
    function doDelete($catch=false)
    {
        if ($catch) {
            if (empty($_SESSION['picture_delete'])){
                return ;
            }
            $deletes = $_SESSION['picture_delete'];
            unset($_SESSION['picture_delete']);
        } // if ($catch)
        
        foreach ($deletes as $id){
            $this->delete($id);
        }
    }

    /**
     * 画像の削除
     *
     * @access public
     * @param integer $id
     * @return integer  データ操作結果
     */
    function delete($id)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }

        $this->objfile->unlink($result['filename']);
        $this->objfile->unlink($result['thumbnail']);

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id = '.$id;
        return $this->objdb->exec($sql);
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_relation
     * @return boolean  真偽値
     */
    function setFix($ref_relation)
    {
        foreach ($this->ids as $id){
            $this->fix($id,$ref_relation);
        }
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_relation
     * @return boolean  真偽値
     */
    function fix($id,$ref_relation)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }
        
        /* コミュニティよう添付画像 */
        if ($this->status == STATUS_PICTURE_COMMUNITY){
            $this->ref_community = $ref_relation;
            $ref_relation = 0;
        }

        // ファイルの保存
        $dir = ARCHIVES_COMMUNITY_PATH.$this->ref_community.'/';

        $large_path = ereg_replace(ARCHIVES_UPLOAD_PATH, $dir, $result['filename']);
        $small_path = ereg_replace(ARCHIVES_UPLOAD_PATH, $dir, $result['thumbnail']);

        $this->objfile->setUID($this->ref_account);
        $this->objfile->setGID($this->ref_community);
        $this->objfile->rename($result['filename'], $large_path);
        $this->objfile->rename($result['thumbnail'], $small_path);
        
        $this->ref_relation = $ref_relation;
        $sql =
            'UPDATE '.
                DB_PREFIX.'com_picture '.
            'SET '.
                "modify='".date('Y-m-d H:i:s')."',".
                'ref_relation='.$this->ref_relation.','.
                'status='.$this->status.','.
                "filename='".$large_path."',".
                "thumbnail='".$small_path."' ".
            'WHERE '.
                'id = '.$id;
        return $this->objdb->exec($sql);
    }

    /**
     * 添付画像IDを削除
     *
     * @access public
     * @return void
     */
    function unSetPicture()
    {
        unset($_SESSION['ref_pictures']);
    }

    /**
     * 添付画像情報の取得
     *
     * @access public
     * @return array
     */
    function getImgInfos()
    {
        $ids = implode(',',$this->ids);

        $sql=
            'SELECT '.
                'id,'.
                'thumbnail as src,'.
                't_width as width,'.
                't_height as height '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id in('.$ids.')';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $list = array();
        $row=0;
        foreach ($result as $value){
            $list[] = $value;
            $row++;
        }
        
        for ($row;$row<3;$row++) {
            $list[] = array(
                'id'=>       null,
                'src'=> NOPHOTO_SMALL,
                'width'=>  PHOTO_SMALL_SIZE,
                'height'=> PHOTO_SMALL_SIZE
            );
        }

        return $list;
    }
}
// community_pictureの終了
?>

==> rktSNS_1.070428.tgz: rktSNS/webapp/libs/community/pictures.php <==
<?php
/* ========================================================================
 - [webapp/libs/community/pictures.php]
 -      コミュニティ関連の添付画像クラス
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2007/01/31] 通常ファイル添付に対応
 -      [2006/07/10] 作成
 - ======================================================================== */

require_once LIB_DIR.'rkt_db.php';
require_once LIB_DIR.'rkt_upload.php';

/**
 * コミュニティ関連の添付画像クラス
 *
 * @author 高橋 裕志郎 <yujiro@stepone.tv>
 * @package community_body
 * @access public
 * @version 1.0
 */
class community_pictures
{
    /**
     * 添付ファイル画像ID
     * @var integer
     */
    var $ids = 0;

    /**
     * コミュニティID
     * @var boolean
     */
    var $ref_community = 0;

    /**
     * ID
     * @var integer
     */
    var $ref_relation = 0;

    /**
     * アカウントID
     * @var integer
     */
    var $ref_account = 0;

    /**
     * ステータス
     * @var integer
     */
    var $status = 0;

    /**
     * DB接続オジェクト
     * @var object
     */
    var $objdb = null;

    /**
     * BLOB操作オブジェクト
     * @var object
     */
    var $objfile = null;

    /**
     * コンストラクタ
     *
     * @access public
     * @param integer $ref_community
     * @param integer $ref_relation
     * @return void
     */
    function community_pictures($ref_community, $ref_relation, $status)
    {
        $this->objdb = RKT_db::getInstance();
        $this->objfile = RKT_upload::getInstance(BLOB_DRIVER,BLOB_PARAM); 

        $this->ref_community = $ref_community;
        $this->ref_relation = empty($ref_relation)?0:$ref_relation;
        $objact = account::getInstance();
        $this->ref_account = $objact->getInfo('id');
        $this->status = $status;        
        $this->set_ids();

        /* 削除画像IDの引継ぎ */
        if (!empty($_POST['picture_delete'])){
            $deletes = array();
            foreach ($_POST['picture_delete'] as $id) {
                $deletes[$id] = $id;
            }
            $_SESSION['picture_delete'] = $deletes;
        } // if (!empty($_POST['picture_delete']))
    }

    /**
     * 添付ファイルIDの取得
     *
     * @access private
     * @return void
     */
    function set_ids()
    {
        if (isSet($_SESSION['ref_pictures'])){
            $this->ids = $_SESSION['ref_pictures'];
            return ;
        } // if (isSet($_SESSION['ref_pictures']))

        $where = ' AND ref_relation = '.$this->ref_relation;
        /* コミュニティよう添付画像 */
        if ($this->status == STATUS_PICTURE_COMMUNITY){
            $where = '';
        }
        
        $sql=
            'SELECT '.
                'id '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'ref_community = '.$this->ref_community.' AND '.
                'status = '.$this->status.
                $where;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        $this->ids = array();
        if (empty($result)){
            return ;
        }

        foreach ($result as $value){
            $this->ids[$value['id']] = $value['id'];
        }
    }

    /**
     * 画像のアップロード処理
     *
     * @access public
     * @return integer  データ操作結果
     */
    function doUpload()
    {
        if (empty($_POST['ref_pictures'])){
            return ;
        }

        $this->ids = array();
        $row = 0;
        foreach ($_POST['ref_pictures'] as $id) {
            if (!empty($id)){
                $this->ids[$id] = $id;
            }
            $this->upload($id, 'photo'.$row);
            $row++;
        }
        $_SESSION['ref_pictures'] = $this->ids;
    }

    /**
     * 画像のアップロード処理
     *
     * @access public
     * @return integer  データ操作結果
     */
    function upload($id, $name)
    {
        /* 一覧用画像 */
        if (!$this->objfile->catchFile($name)) {
            return false;
        }

        // ファイルの保存
        $dir = ARCHIVES_UPLOAD_PATH;
        $filename = $this->objfile->getName();
        $extension = $this->objfile->getExtension();

        $temp = md5($this->ref_account.time());
        $name = substr($temp, rand(0,25), 6);

        $large_path = $dir.'large/'.$name.'.'.$extension;
        $small_path = $dir.'small/'.$name.'.'.$extension;

        // ファイルの保存
        if ($this->objfile->isImage()){
            $large = $this->objfile->saveResize($large_path,PHOTO_MAX_SIZE, PHOTO_MAX_SIZE);
            $small = $this->objfile->saveResize($small_path,PHOTO_SMALL_SIZE,PHOTO_SMALL_SIZE);
        } else {
            $res = $this->objfile->saveUpfile($large_path);
            $large = array('width'=>0,'height'=>0);
            $small_path = 'resource/img/common/';
            $small_path .= preg_match("/pdf/i", $mime_type)?'pdf.gif':'other.gif';
            $small = array('width'=>52,'height'=>55);
        }

        $values = array(
            'title'=> $filename,
            'filename'=> $large_path,
            'width'=> $large['width'],
            'height'=> $large['height'],
            'thumbnail'=> $small_path,
            't_width'=> $small['width'],
            't_height'=> $small['height'],
        );

        if (empty($id)){
            $this->insert($values);
        } else {
            $this->update($id,$values);
        }
        return true;
    }

    /**
     * 添付画像を新規登録
     *
     * @access private
     * @param array $values
     * @return boolean  真偽値
     */
    function insert($values)
    {
        $sql =
            'INSERT INTO '.
                DB_PREFIX.'com_picture('.
                    'modify,'.
                    'ref_community,'.
                    'ref_account,'.
                    'title,'.
                    'filename,'.
                    'width,'.
                    'height,'.
                    'thumbnail,'.
                    't_width,'.
                    't_height'.
                ') VALUES ('.
                    "'".date('Y-m-d H:i:s')."',".
                    $this->ref_community.','.
                    $this->ref_account.','.
                    "'".$values['title']."',".
                    "'".$values['filename']."',".
                    $values['width'].','.
                    $values['height'].','.
                    "'".$values['thumbnail']."',".
                    $values['t_width'].','.
                    $values['t_height'].
                ')';
        $result = $this->objdb->exec($sql);
        if ($result){
            $id = $this->objdb->lastInsertId();
            $this->ids[$id] = $id;
        }
        return $result;
    }

    /**
     * 添付画像を更新
     *
     * @access private
     * @param integer $id
     * @param array $values
     * @return boolean  真偽値
     */
    function update($id,$values)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (!empty($result)){
            $this->objfile->unlink($result['filename']);
            $this->objfile->unlink($result['thumbnail']);
        }

        $sql =
            'UPDATE '.
                DB_PREFIX.'com_picture '.
            'SET '.
                "modify='".date('Y-m-d H:i:s')."',".
                "title='".$values['title']."',".
                "filename='".$values['filename']."',".
                'width='.$values['width'].','.
                'height='.$values['height'].','.
                "thumbnail='".$values['thumbnail']."',".
                't_width='.$values['t_width'].','.
                't_height='.$values['t_height'].' '.
            'WHERE '.
                'id = '.$id;
        $result = $this->objdb->exec($sql);
        if ($result){
            $this->ids[$id] = $id;
        }
        return $result;
    }

    /**
     * 画像の削除
     *
     * @access public
     * @param boolean $cahtch
     * @return integer  データ操作結果
     */
    function doDelete($catch=false)
    {
        if ($catch) {
            if (empty($_SESSION['picture_delete'])){
                return ;
            }
            $deletes = $_SESSION['picture_delete'];
            unset($_SESSION['picture_delete']);
        } // if ($catch)
        
        foreach ($deletes as $id){
            $this->delete($id);
        }
    }

    /**
     * 画像の削除
     *
     * @access public
     * @param integer $id
     * @return integer  データ操作結果
     */
    function delete($id)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'width,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }

        $this->objfile->unlink($result['filename']);
        if (!empty($result['width'])){
            $this->objfile->unlink($result['thumbnail']);
        }

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id = '.$id;
        return $this->objdb->exec($sql);
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_relation
     * @return boolean  真偽値
     */
    function setFix($ref_relation)
    {
        foreach ($this->ids as $id){
            $this->fix($id,$ref_relation);
        }
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_relation
     * @return boolean  真偽値
     */
    function fix($id,$ref_relation)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'width,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }
        
        /* コミュニティよう添付画像 */
        if ($this->status == STATUS_PICTURE_COMMUNITY){
            $this->ref_community = $ref_relation;
            $ref_relation = 0;
        }

        // ファイルの保存
        $dir = ARCHIVES_COMMUNITY_PATH.$this->ref_community.'/';

        $large_path = ereg_replace(ARCHIVES_UPLOAD_PATH, $dir, $result['filename']);
        $small_path = ereg_replace(ARCHIVES_UPLOAD_PATH, $dir, $result['thumbnail']);


        $this->objfile->setUID($this->ref_account);
        $this->objfile->setGID($this->ref_community);
        $this->objfile->rename($result['filename'], $large_path);
        if (!empty($result['width'])){
            $this->objfile->rename($result['thumbnail'], $small_path);
        } else {
            $small_path = $result['thumbnail'];
        }
        
        $this->ref_relation = $ref_relation;
        $sql =
            'UPDATE '.
                DB_PREFIX.'com_picture '.
            'SET '.
                "modify='".date('Y-m-d H:i:s')."',".
                'ref_relation='.$this->ref_relation.','.
                'status='.$this->status.','.
                "filename='".$large_path."',".
                "thumbnail='".$small_path."' ".
            'WHERE '.
                'id = '.$id;
        return $this->objdb->exec($sql);
    }

    /**
     * 添付画像IDを削除
     *
     * @access public
     * @return void
     */
    function unSetPicture()
    {
        unset($_SESSION['ref_pictures']);
    }

    /**
     * 添付画像情報の取得
     *
     * @access public
     * @return array
     */
    function getImgInfos()
    {
        $ids = implode(',',$this->ids);

        $sql=
            'SELECT '.
                'id,'.
                'thumbnail as src,'.
                't_width as width,'.
                't_height as height '.
            'FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'id in('.$ids.')';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $list = array();
        $row=0;
        foreach ($result as $value){
            $list[] = $value;
            $row++;
        }
        
        for ($row;$row<3;$row++) {
            $list[] = array(
                'id'=>       null,
                'src'=> NOPHOTO_SMALL,
                'width'=>  PHOTO_SMALL_SIZE,
                'height'=> PHOTO_SMALL_SIZE
            );
        }

        return $list;
    }
}
// community_pictureの終了
?>
